<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Kattintson az alkalmazáshoz való visszatéréshez</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Takarítás</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 elem</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Fájlnév</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Újra</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Állj</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Podcast publikálása a YouTubera</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Szerző</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Tábla</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumentumok</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Képernyő eszköztár</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Hátterek</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Háttér váltása</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Újra</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Előző oldal</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Következő oldal</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Dokumentumok kezelése</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Web böngészés</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Előre</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Újratöltés</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Kezdőlap</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Könyvjelzők</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Könyvjelző</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Könyvtár</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Asztal megjelenítése</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Nagyobb</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Kisebb</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Új mappa</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Új dokumentum</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importálás</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Megnyitás a Táblán</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Másolat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Hozzáadás a nyitott dokumentumhoz</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Kiválasztott tartalom hozzáadása a megnyitott dokumentumhoz</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Eszközök</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Több kijelző</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Széles méret (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>szabályos méret (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Egyéni méret</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Betöltés megállítása</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Kivágás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Alvó mód</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuális billentyűzet</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Sima világos háttér</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Világos</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Rács világos háttéren</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Sima sötét háttér</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Sötét</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Rács sötét háttéren</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Felvétel</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Képernyő felvétel indítása</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Elem törlése</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Jegyzetek törlése</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Oldal törlése</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Toll</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Frissítés ellenőrzése</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Radír</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Jelölő</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Kiválasztó</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Kéz</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Kicsinyítés</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Vonal</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Keskeny vonal</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Közepes vonal</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Vastag vonal</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Kis radír</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Közepes radír</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Nagy radír</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Szín</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Aktuális oldal újratöltése</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Kezdőoldal betöltése</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Könyvjelzők megjelenítése</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Könyvjelző hozzáadása</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Tábla megjelenítése</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Tartalom törlése</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Tulajdonágok megjelenítése</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Könyvtár megjelenítése</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Számítógép Asztal megjelenítése</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Új mappa létrehozása</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Új dokumentum létrehozása</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Dokumentum importálása</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Dokumentum exportálása</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Oldal megnyitása a Táblán</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Kiválasztott tartalom megkettőzése</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Kijelölt tartalom törlése</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Tartalom hozzáadása a dokumentumhoz</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Tartalom átnevezése</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Eszközök megjelenítése</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Széles méretű dokumentum (16:9)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Szabályos dokumentumméret (4/3)</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Egyéni documentumméret</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Weboldal betöltésének megállítása</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Prezentáció alvó módba helyezése</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Virtuális billentyűzet megjelenítése</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Prezentáció rögzítése videóban</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Minden elem törlése</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Minden jegyzet törlése</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Minden elem törlése</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Dokuemtum kijegyzetelése</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Jegyzet törlése</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Kiemelő </translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Objektumok kiválasztása és módosítása</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Oldal görgetése</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Lézermutató</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Virtuális lézermutató</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Vonal rajzolása</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Szöveg írása</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Metszet</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Hozzáadás a jelenlegi oldalhoz</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Elem hozzáadása a jelenlegi oldalhoz</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Hozzáadás új oldalhoz</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Tartalom hozzáadása új oldalhoz</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Hozzáadás a könyvtárhoz</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Tartalom hozzáadása a könyvtárhoz</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Oldalak</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Úl oldal létrehozása</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Új oldal</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Oldal megkettőzése</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Jelenlegi oldal megkettőzése</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Oldal importálása</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Külső oldal importálása</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Podcast felvétel szüneteltetése</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Podcast konfigurálása</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Podcast felvétel beállítasai</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Flash rögzítése</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Flash tartalom rögzítése</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Web rögzítése</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Webes tartalom rögzítése</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Képernyőrészlet metszet</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Egyéni metszet</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Albakmetszet</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Webes tartalom beágyazása</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Beágyazott webtartalom metszet</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Kezdőképernyő megjelenítése a kijelzőn</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Minden jegyzet törlése</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>eduMedia szimuláció importálása</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Ablak metszet</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Megjelenítés a kijelzőn</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Kilépés az OpenBoardból</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>OpenBoard elrejtése</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>OpenBoard alkalmazás elrejtése</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Elemek mozgatása</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Háttér törlése</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Háttér eltávolítása</translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>Útmutató megnyitása</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>Útmutató weboldal megnyitása</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation>Vonalazott világos háttér</translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation>Vonalazott sötét háttér</translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation>Rácsméret alaphelyzetbe állítása</translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Hitelesítés szükséges</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Proxy hitelesítés</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Kapcsolódás a proxyhoz</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Felhasználónév:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Jelszó:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Felhasználónév és jelszó mentése</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Remove Page</source>
        <translation>Oldal eltávolítása</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Biztosan el akarsz távolítani 1 oldalt a kiválasztott dokumentumból &apos;%0&apos;?</translation>
    </message>
    <message>
        <source>Element ID = </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Oldal méret</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Új frissítés elérhető. Szeretne ellátogatni a weboldalra?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Nincs elérhető frissítés</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Frissítés elérhető</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>Board drawing...</source>
        <translation type="vanished">Tábla rajzolása...</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation>Rács mérete</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>%1 tartalom letöltése sikertelen</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Letöltés befejezve</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Ismeretlen eszköz típus: %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Ismeretlen tartalom típus: %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Elem hozzáadása</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Mind támogatott (%1)</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>%1. oldal törölve</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Fájl hozzáadása sikertelen: Fájl másolási hiba</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Csoportosítás</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Csoport bontás</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>Dokumentum mentése...</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>Dokumentum éppen most mentve...</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation>%1. oldal törlése</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Szín</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Hiba a kép könyvtárhoz adásakor</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>KépMetszet</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation>Oldalak betöltése (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Átmeneti tároló tulajonságok</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Szín:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Alak:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Képernyőrészlet metszése</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Képernyőmentés</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Képernyőeszköztár megjelenítése</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Tábla megjelenítése a második kijelzőn</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Asztal  megjelenítése a második kijelzőn</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>OpenBoard megjelenítése</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Új mappa</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>%1. oldal</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Képeket tartalmazó mappa hozzáadása</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Képek hozzáadása</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Oldalak hozzáadása fájlból</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>%1 dokumentum megkettőzve</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>%1 dokumentum átmásolva</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Oldal eltávolítása</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Documentum eltávolítása</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Biztosan szeretné eltávolítani a &apos;%1&apos; dokumentumot?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Kuka kiürítése</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Biztosan szeretné a kukát üríteni?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Kuka kiürítése folyamatban</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Kuka kiürítve</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Mappa eltávolítása</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Biztosan eltávolítja a(z) &apos;%1&apos; mappát és minden tartalmát?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Nincs dokumentum kiválasztva!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Támogatott fájl megnyitása</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>%1 fájl importálása...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Fájl importálása sikertelen ... </translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Minden kép importálása  mappából</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Üres</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Kuka</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Dokumentum megnyitása</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Minden kép hozzáadása a Dokumentumhoz</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Minden kép (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>A kiválasztásban nincs egyetlen kép sem!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Biztosan szeretne eltávolítani %n oldalt a kiválasztott &apos;%1&apos; dokumentumból?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>A mappa nem tartalmaz egyetlen képet sem</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Névtelen dokumentumok</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>A &apos;%1&apos; dokumentum az OpenBoard újabb verziójával (%2) készült. Megnyitásával néhány információ elveszhet. Szeretné folytatni?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all selected documents?</source>
        <translation type="vanished">Biztosan szeretne eltávolítani minden kiválasztott dokumentumot?</translation>
    </message>
    <message>
        <source>Remove multiple documents</source>
        <translation type="vanished">Több dokumentum eltávolítása</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>képek</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>videók</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>objektumok</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>minialkalmazások</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Minden támogatott fájl (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>%1 fájl mentve</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>%2 / %1 oldal beszúrása</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importálás sikeres.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>%1 fájl importálása sikeres.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>%1 fájl importálása</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Elfogad</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Mégse</translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Kuka</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 oldal másolva</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">%1/%2 oldal másolása</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 oldal másolva</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (másolás)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">%1/%2 oldal másolása</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 oldal másolva</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Fájlok letöltése</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation>Oldal %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Figyelmeztetés jelent meg az exportálás alatt</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Dokumentum exportálása...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exportálás sikertelen</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation>Az exportálás nem lehetséges a kiválasztott helyre. Nincs megfelelő jogosultsága a fájl mentésére.</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation>Exportálás sikertelen: célhely nem írható</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportálás sikeres.</translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Dokumentum exportálása...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Exportálás sikeres.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">Exportálás sikertelen.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>oldal</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exportálás UBZ fájlként</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>%1 exportálása %2/%3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>Exportálás OpenBoard formátumba</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Dokumentum exportálása...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Exportálás sikeres.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">Exportálás sikertelen.</translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportálás PDF fájlként</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportálás PDFbe</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportálás PDF fájlként</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>%2 / %1 oldal exportálása</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportálás PDFbe</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>oldal</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exportálás WEB adatként</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Dokumentum exportálása...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportálás sikeres.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Exportálás sikertelen.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exportálás WEB Böngészőbe</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Hozzáadás az oldalhoz</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Hozzáadás könyvtárhoz</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Objektum információk</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Hozzáadás a kedvencekhez</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Megosztás</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Vissza a mappába</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Új mappa létrehozása</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Fájlrendszer újraolvasása</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>ImportáltKépek</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Hangok</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filmek</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Képek</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animációk</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interaktívok</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Alkalmazások</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Alakzatok</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Kedvencek</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Webes keresés</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Kuka</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Elfogad</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Írjon be egy új mappa nevet</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Betöltés </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Zárolva</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Látható a kiterjesztett képernyőn</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Zárolva</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Látható a kiterjesztett képernyőn</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Ugrás a tartalom forrásához</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>Beállítás háttérként</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation>Média erőforrás nem oldható fel</translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>Nem támogatott média formátum</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation>Média lejátszó szolgáltatás nem található</translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>Média hiba: </translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Szöveg helye&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Szöveg színe</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Szerkeszthető</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Betöltés ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Rögzített</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Átalakítás eszközként </translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation type="unfinished">%1 fájl importálása...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation type="unfinished">%1 fájl importálása sikertelen.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation type="unfinished">Importálás sikeres.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>%1 fájl importálása...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importálás sikeres.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>%1 fájl importálása sikertelen.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Kép formátum (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>PDF importálása sikertelen.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>%2 / %1 oldal importálása</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Hiba a videó intranetre való publikálása közben (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Intranetre publikálás folyamatban %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publikálás</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Igen</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nem</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Felhasználónév és jelszó megadása &quot;%1&quot; -hoz %2 -nál&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Sikertelen a belépés a proxyra</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>SSL hibák:

%1

%2

Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Igen</translation>
    </message>
    <message>
        <source>No</source>
        <translation>NEM</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation>Open-Sankoré dokumentumok észlelve</translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation>Ezen ablak megjelenítése a következő alkalommal</translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation>Mindig elérheti az OpenBoard Importálót a Tulajdonságok panelen a Rólunk fülön. Figyelem, ha már importálta az Open-Sankoré adatait, elveszítheti az aktuális OpenBoard dokuemntumait.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation>Open-Sankoré dokumentumok vannak a számítógépén. Importálásuk az OpenBoardba, a &quot;FOLYTATÁS&quot; gombra kattintva, az elinduló importáló alkalmazással lehetséges.</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(másolás)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Dokumentum repository veszteség</translation>
    </message>
    <message>
        <source>has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="vanished">elveszítette a &apos;%1&apos; dokumentum repository hozzáférését. Sajnálatosan az alkalmazásnak le kellett állnia, hogy elkerülje az adatsérülést. A legutóbbi változtatások elveszhettek.</translation>
    </message>
    <message>
        <source>Moving page to trash folder...</source>
        <translation type="vanished">Oldal áthelyezése a kukába...</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Angol</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Orosz</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Német</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francia</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Svájci-francia</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Sikertelen a kódoló indítása...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Nincs elérhető podcast kódoló ...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>%1. rész</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>az asztalán ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>%1 mappában</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>%1 podcast létrehozva</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Podcast rögzítési hiba (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Alapértelmezett Hang bemenet</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Nincs hangfelvétel</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Teljes</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publikálás az Intranetre</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publikálás a YouTubera</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation>OpenBoard cast</translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>verziószám: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>A jelölőtoll nyomásérzékeny</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Proxy belépés</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Felhasználónév:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Jelszó:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Dokumentum publikálása a WEBre</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Cím:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Leírás:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publikálás</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Videóim</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation>Legközelebb látható</translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Előképek létrehozása...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 előkép létrehozva...</translation>
    </message>
    <message>
        <source>loading thumbnail of page %1</source>
        <translation type="vanished">%1. oldal előképének betöltése</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation>oldal %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Maszk</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Vonalzó</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Iránytű</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Szögmérő</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Háromszögvonalzó</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Nagyító</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Gyorsítótár</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Teljes oldal</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Dokumentum frissítő</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> A fájlok frissítést igényelnek.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Biztonsági mentési útvonal: </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Tallózás</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Válassza ki a biztonsági mentés mappáját</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>A fájlok frissítése sikeres. Kérem, hogy indítsa újra az alkalmazást, hogy hozzáférhessen a frissített dokumentumokhoz.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>A frissítés közben hiba lépett fel. A fájlok nem sérültek.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Fájl frissítés eredménye</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Fájl frissítése </translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Kérem várjon. Az importálási folyamat hamarosan elindul...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Később emlékeztessen</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Betöltés ...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 called (method=%1, status=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>YouTube hitelesítés sikertelen.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Hiba a videó YouTubera való feltöltése közben (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Feltöltés a Youtubera folyamatban %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Feltöltés</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Autók &amp; Járművek</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Zene</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Házi kedvencek @ Állatok</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Utazás &amp; Események</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Játék</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Vígjáték</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Emberek &amp; Blogok</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Hírek &amp; Politika</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Szórakoztatás</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Oktatás</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Hogyan Csináld &amp; Stílus</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>NonProfit &amp; Aktivisták</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Tudomány &amp; Technológia</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Tisztítás</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Letölés megszakítva: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Hiba a mentett állomány megnyitása közben: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Hiba a mentés közben: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Hálózati hiba: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>másodperc</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>perc</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 maradt</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 / %2 (%3/mp) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 / %2 - Megállítva</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 Letöltés</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Letöltés</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Megnevezés</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cím</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Korábban ma</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 elem</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Új fül &amp;T</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Fül másolása</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Fül bezárása &amp;C</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Többi fül bezárása &amp;O</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Fül frissítése</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Minden fül frissítése</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Mostanában bezárt fülek</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Névtelen)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Nincs keresési előzmény</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Keresési előzmények</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Keresési előzmények törlése</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Hozzaadás az aktuális dokumentumhoz</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Hiba a %1 . oldal betöltése közben</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation>PDF letöltése: Jobban szeretné letölteni a PDF fájlt vagy hozzáadné az aktuális dokumentumhoz?</translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Megnyitás új fülön</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Podcast publikálása YouTubera</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Kulcsszavak</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategória</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>YouTube felhasználónév</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>YouTube jelszó</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;A &apos;Feltöltés&apos; gombra kattintva tanusítod, hogy a tartalom minden jogával rendelkezel vagy a tulajdonos hatalmazott fel, hogy publikusan elérhetővé tedd a tartlmat a YouTubeon és eznem sérti a YouTube felhasználási feltételeit, ami itt található meg: &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation>Meghatalmazás visszaállítása újraindításkor</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>Opacity</source>
        <translation>Átlátszatlanság</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Világos háttéren</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Sötét háttéren</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Vonal vastagság</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Erős</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>finom</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>A toll nyomásérzékeny</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation>Kör előnézet megjelenítése</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Párbeszéd</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Szerző</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation>OpenBoard Dokumentumok</translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Alapbeállítások</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Megjelenítés</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Oldal megjelenítése külső böngészővel</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuális billentyűzet</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Felülre állítva (Táblagépekhez ajánlott)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Alulra állítva (fehér táblákhoz ajánlott)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Szöveg megjelenítése a gombok alatt</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Képernyő eszköztár</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Vízszintes</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Függőleges</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Szoftver frissítés</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Frissítés ellenőrzése indításkor</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Kezdőoldal:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Eszköztár</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Toll</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Jelölőtoll</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>verziószám: ...</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licenszek</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Belső weboldal megjelenítése a másodlagos kijelzőn vagy projektoron</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Több kijelző</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Vezérlő és megjelenítő kijelző megcserélése</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Ebben a módban induljon:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tábla</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy felhasználó:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Jelszó:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Készítők</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation>Open-Sankoré importáló</translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation>Ellenőrizze ha lehet, hogy Open-Sancoré adatokat kell importálni az indításkor</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>Rendszer billentyűzet használata (ajánlott)</translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>Beépített virtuális billentyűzet gomb méret:</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>Rács</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Sötét háttéren</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Átlátszatlanság</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Világos háttéren</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Flash rögzítése</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Flash kiválasztása a rögzítéshez</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Alkalmazás neve</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Alkalmazás létrehozása</translation>
    </message>
</context>
</TS>
